==> gmssl-jsse-provider-1.0.1-20191211.090138-1-sources.jar: org/bouncycastle/tls/crypto/impl/bc/BcTlsSM2VerifierSdf.java <==
package org.bouncycastle.tls.crypto.impl.bc;

import com.xdja.pki.gmssl.crypto.sdf.SdfCryptoType;
import com.xdja.pki.gmssl.crypto.sdf.SdfSM2BaseSigner;
import com.xdja.pki.gmssl.crypto.sdf.SdfSM2Signer;
import com.xdja.pki.gmssl.crypto.sdf.SdfSM2SignerSM3;
import com.xdja.pki.gmssl.sdf.SdfSDKException;
import org.bouncycastle.crypto.params.AsymmetricKeyParameter;
import org.bouncycastle.tls.AlertDescription;
import org.bouncycastle.tls.DigitallySigned;
import org.bouncycastle.tls.TlsFatalAlert;

/**
 * Implementation class for the verification of the raw ECDSA signature type using the BC light-weight API.
 */
public class BcTlsSM2VerifierSdf extends BcTlsVerifier {

    public BcTlsSM2VerifierSdf(BcTlsCryptoSdf crypto, AsymmetricKeyParameter publicKey) {
        super(crypto, publicKey);
    }

    @Override
    public boolean verifyRawSignature(DigitallySigned signedParams, byte[] hash) throws TlsFatalAlert {
        try {
            SdfSM2BaseSigner signer;
            BcTlsCryptoSdf cryptoSdf = (BcTlsCryptoSdf) this.crypto;
            if (cryptoSdf.isUseBC()) {
                signer = new SdfSM2SignerSM3(cryptoSdf.getSdfCryptoType());
            } else {
                signer = new SdfSM2Signer(cryptoSdf.getSdfCryptoType());
            }
            signer.init(false, publicKey);
            signer.update(hash, 0, hash.length);
            boolean is = signer.verifySignature(signedParams.getSignature());
            signer.release();
            return is;
        } catch (SdfSDKException e) {
            throw new TlsFatalAlert(AlertDescription.internal_error, e);
        }
    }
}

==> gmssl-jsse-provider-1.3.4-20220406.062557-6-sources.jar: org/bouncycastle/tls/crypto/impl/bc/BcTlsSM2VerifierSdf.java <==
package org.bouncycastle.tls.crypto.impl.bc;

import com.xdja.pki.gmssl.crypto.sdf.SdfECBaseSigner;
import com.xdja.pki.gmssl.crypto.sdf.SdfECSigner;
import com.xdja.pki.gmssl.crypto.sdf.SdfEcSignerWithSoftDigest;
import com.xdja.pki.gmssl.sdf.SdfSDKException;
import org.bouncycastle.crypto.params.AsymmetricKeyParameter;
import org.bouncycastle.tls.AlertDescription;
import org.bouncycastle.tls.DigitallySigned;
import org.bouncycastle.tls.TlsFatalAlert;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * Implementation class for the verification of the raw ECDSA signature type using the BC light-weight API.
 */
public class BcTlsSM2VerifierSdf extends BcTlsVerifier {

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    public BcTlsSM2VerifierSdf(BcTlsCryptoSdf crypto, AsymmetricKeyParameter publicKey) {
        super(crypto, publicKey);
    }

    @Override
    public boolean verifyRawSignature(DigitallySigned signedParams, byte[] hash) throws TlsFatalAlert {
        try {
            SdfECBaseSigner signer;
            BcTlsCryptoSdf cryptoSdf = (BcTlsCryptoSdf) this.crypto;
            if (cryptoSdf.isUseBC()) {
                signer = new SdfEcSignerWithSoftDigest(cryptoSdf.getSdfCryptoType());
            } else {
                signer = new SdfECSigner(cryptoSdf.getSdfCryptoType());
            }
            signer.init(false, publicKey);
            signer.update(hash, 0, hash.length);
            byte[] signature = signedParams.getSignature();
            boolean verified = signer.verifySignature(signature);
            signer.release();
            return verified;
        } catch (SdfSDKException e) {
            throw new TlsFatalAlert(AlertDescription.internal_error, e);
        }
    }
}
